//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/Aggregate/InterferenceRadialParaCrystal.h
//! @brief     Defines class InterferenceRadialParaCrystal.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCERADIALPARACRYSTAL_H
#define BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCERADIALPARACRYSTAL_H

#include "Sample/Aggregate/IInterference.h"
#include "Sample/Correlations/FTDistributions1D.h"
#include <heinz/Complex.h>
#include <memory>

//! Interference function of radial paracrystal.
//! @ingroup interference

class InterferenceRadialParaCrystal : public IInterference {
public:
    inline static const std::string class_name = "InterferenceRadialParaCrystal";
    std::string className() const final { return class_name; }

    InterferenceRadialParaCrystal(double peak_distance, double damping_length);
    InterferenceRadialParaCrystal* clone() const override;

    void accept(INodeVisitor* visitor) const override { visitor->visit(this); }

    void setKappa(double kappa);
    double kappa() const;

    void setDomainSize(double size);
    double domainSize() const { return m_domain_size; }

    complex_t FTPDF(double qpar) const;

    void setProbabilityDistribution(const IFTDistribution1D& pdf);

    double peakDistance() const { return m_peak_distance; }

    double dampingLength() const { return m_damping_length; }

    std::vector<const INode*> getChildren() const override;

    double randomSample() const { return m_pdf->createSampler()->randomSample(); }

private:
    double iff_without_dw(R3 q) const override;
    void init_parameters();

    double m_peak_distance;  //!< the distance to the first neighbor peak
    double m_damping_length; //!< damping length of paracrystal
    //! Fourier transformed probability distribution of the nearest particle
    std::unique_ptr<IFTDistribution1D> m_pdf;
    bool m_use_damping_length;
    double m_kappa;       //!< Size-spacing coupling parameter
    double m_domain_size; //!< Size of coherence domain
};

#endif // BORNAGAIN_SAMPLE_AGGREGATE_INTERFERENCERADIALPARACRYSTAL_H
